# [Pdf-To-Image](https://github.com/starkblaze01/Pdf-To-Image)
Simple Command Line tool to convert PDF to Image.
This package is still in the beta-version.

# For Using the package
- Run `pdftoimg -h`
